SystemOrganization addCategory: #'Z3950-FFI'!
SystemOrganization addCategory: #'Z3950-Core'!
SystemOrganization addCategory: #'Z3950-Databases'!
SystemOrganization addCategory: #'Z3950-Options'!
SystemOrganization addCategory: #'Z3950-RecordFormats'!
SystemOrganization addCategory: #'Z3950-Attributes'!
SystemOrganization addCategory: #'Z3950-Data'!
SystemOrganization addCategory: #'Z3950-APT'!

!String methodsFor: '*Z3950' stamp: 'hfm 6/12/2010 06:08'!
asZ3950Server

	^ Z3950ServerRepository new serverAt: self! !

!String methodsFor: '*Z3950' stamp: 'hfm 12/5/2010 14:10'!
pqfSyntax

	^ self! !

Association subclass: #Z3950Attribute
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

!Z3950Attribute commentStamp: 'hfm 10/19/2009 20:05' prior: 0!
An attribute according to PQF/RPN semantics, contained by an Z3950AttributeSet in its attribute map. You don't need to create instances of this class manually, all of them live in the class side of each attribute set.!

!Z3950Attribute methodsFor: 'accessing' stamp: 'hfm 10/19/2009 05:47'!
attributeName
	^ key! !

!Z3950Attribute methodsFor: 'accessing' stamp: 'hfm 10/19/2009 05:47'!
attributeName: anObject
	key := anObject! !

!Z3950Attribute methodsFor: 'accessing' stamp: 'hfm 10/19/2009 05:47'!
attributeNumber
	^ value! !

!Z3950Attribute methodsFor: 'accessing' stamp: 'hfm 10/19/2009 05:47'!
attributeNumber: anObject
	value := anObject! !

Z3950Attribute subclass: #Z3950DefaultAttribute
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

ExternalLibrary subclass: #Z3950FFILibrary
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

Z3950FFILibrary class
	instanceVariableNames: 'default'!

!Z3950FFILibrary commentStamp: 'hfm 5/4/2009 13:25' prior: 0!
A Z3950FFILibrary is the interface to Indexdata's Zoom functions compiled in the YAZ dynamic link library (YAZ.DLL)

Example:

| zConn results record records resultSetSize |

zConn := Z3950FFILibrary default createConnectionTo: 'localhost' port: 210.
Z3950FFILibrary default createOptions.
Z3950FFILibrary default 
	setConnection: zConn 
	optionName: 'databaseName' 
	optionValue: ''.
Z3950FFILibrary default 
	setConnection: zConn 
	optionName: 'preferredRecordSyntax' 
	optionValue: 'USMARC'.
				
results := Z3950FFILibrary default 
				searchPqf: zConn 
				query: '@attr 1=1003 collins'.

resultSetSize := Z3950FFILibrary default resultSetSize: results.
records := Array new: resultSetSize.
" First record has position zero "
0 to: resultSetSize - 1 do: [: pos |
	record := Z3950FFILibrary default resultSetRecord: results position: pos.
	records 
		at: pos + 1 
		put: ( Z3950FFILibrary default 
				getRecord: record 
				function: 'render; charset=marc8, iso8859-1' 
				length: nil ).	
	
	 ].
records inspect.
!

Z3950FFILibrary class
	instanceVariableNames: 'default'!

!Z3950FFILibrary class methodsFor: 'instance creation' stamp: 'hfm 2/25/2009 13:02'!
createInstance

	^ self basicNew! !

!Z3950FFILibrary class methodsFor: 'accessing' stamp: 'hfm 2/25/2009 13:04'!
default
	" Answer the receiver's instance, Convenience method "

	^ self uniqueInstance! !

!Z3950FFILibrary class methodsFor: 'instance creation' stamp: 'hfm 2/25/2009 13:02'!
instanceCreationErrorString

	^'This is a singleton implementation, so you are not allowed to create instances yourself. 
Use #uniqueInstance to access the instance.'! !

!Z3950FFILibrary class methodsFor: 'accessing' stamp: 'hfm 12/19/2010 14:13'!
moduleName

	| answer |
	
	answer := String empty.
	Smalltalk isWin32
		ifTrue: [ answer := 'yaz3.dll' ].  " Rename to yaz4.dll if external module not found "
	Smalltalk isMacOS
		ifTrue: [ answer := 'libyaz.3.dylib' ].
	Smalltalk isUnix
		ifTrue: [ answer := 'libyaz.so' ]. " Rename to libyaz.so.4.0 if external module not found "
	^ answer! !

!Z3950FFILibrary class methodsFor: 'instance creation' stamp: 'hfm 2/25/2009 13:03'!
new

	^ self error: self instanceCreationErrorString! !

!Z3950FFILibrary class methodsFor: 'instance creation' stamp: 'hfm 2/25/2009 13:03'!
resetUniqueInstance
	" self resetUniqueInstance "

	default
		ifNotNil: [ default := nil ]! !

!Z3950FFILibrary class methodsFor: 'instance creation' stamp: 'hfm 2/25/2009 13:03'!
uniqueInstance

	default 
		ifNil: [ default := self createInstance ].
	^ default! !

!Z3950FFILibrary methodsFor: 'primitives connection' stamp: 'hfm 2/25/2009 12:58'!
connect: aZoomConnection host: aHostString port: aPortNumber
	" Z3950FFILibrary connect: aZoomConnection host: '' port: 210 "
	
	<cdecl: void '_ZOOM_connection_connect@12' (ZOOMConnection char * short) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives error handling' stamp: 'hfm 4/25/2009 15:38'!
connectionDiagset: aZoomConnection
	" Answer a String - Translates error code into human-readable string "
	
	<cdecl: char * '_ZOOM_connection_diagset@4' (ZOOMConnection) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives connection' stamp: 'hfm 2/25/2009 12:58'!
connectionError: aZoomConnection info: aZOOMErrorMessage additional: aZOOMAdditionalInfo
	" Z3950FFILibrary 
		connectionError: aZoomConnection 
		info: anInfoString 
		additional: anAddInfoString
	"
	
	<cdecl: short * '_ZOOM_connection_error@12' (ZOOMConnection ZOOMErrorMessage * ZOOMAdditionalInfo *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives connection' stamp: 'hfm 4/25/2009 17:29'!
connectionIsIdle: aZOOMConnection
	" Answer 1 if connection is idle (no active or pending work) 0 if not "	
	
	<cdecl: short '_ZOOM_connection_is_idle@4' (ZOOMConnection) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives query' stamp: 'hfm 12/5/2010 12:33'!
cqlQuery: aZOOMQuery
	" The ZOOM_query_cql specifies a CQL query to be sent to the server/target "
	
	<cdecl: short '_ZOOM_query_cql@8' (ZOOMQuery) module: 'yaz3'>
	^ self externalCallFailed
	! !

!Z3950FFILibrary methodsFor: 'primitives connection' stamp: 'hfm 5/4/2009 13:25'!
createConnection: aZoomOptions
	" Z3950FFILibrary default createConnection: Z3950FFILibrary createOptions "
	
	<cdecl: ZOOMConnection '_ZOOM_connection_create@4' (ZOOMOptions) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives connection' stamp: 'hfm 2/25/2009 12:58'!
createConnectionTo: aHostString port: aPortNumber
	" create connection, connect to host, if portnum is 0, then port is
	read from host string (e.g. myhost:9821) "
	" Z3950FFILibrary createConnectionTo: '' port: 210 "
	
	<cdecl: ZOOMConnection '_ZOOM_connection_new@8' (char * short) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives options' stamp: 'hfm 5/4/2009 13:27'!
createOptions
	" Before configuring any options, create the option set
	in the receiver "
	" Z3950FFILibrary default createOptions "
	
	<cdecl: ZOOMOptions '_ZOOM_options_create@0' (void) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives packages' stamp: 'hfm 4/25/2009 17:42'!
createPackage: aZOOMConnection options: aZOOMOptions
	" Creates a package for the connection given using the options specified. "
	
	<cdecl: ZOOMPackage '_ZOOM_connection_package@8' (ZOOMConnection ZOOMOptions) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives query' stamp: 'hfm 4/6/2009 16:15'!
createQuery
	" Z3950FFILibrary default createQuery "
	
	<cdecl: ZOOMQuery '_ZOOM_query_create@0' (void) module: 'yaz3'>
	^ self externalCallFailed
	! !

!Z3950FFILibrary methodsFor: 'primitives connection' stamp: 'hfm 2/25/2009 12:58'!
destroyConnection: aZoomConnection
	" Z3950FFILibrary destroyConnection: "
	
	<cdecl: void '_ZOOM_connection_destroy@4' (ZOOMConnection) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives options' stamp: 'hfm 4/25/2009 18:11'!
destroyOptions: aZOOMOptions
	" Z3950FFILibrary destroyOptions: Z3950FFILibrary createOptions "
	
	<cdecl: void '_ZOOM_options_destroy@4' (ZOOMOptions) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives packages' stamp: 'hfm 4/25/2009 18:23'!
destroyPackage: aZOOMPackage
	
	<cdecl: void '_ZOOM_package_destroy@4' (ZOOMPackage) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives release' stamp: 'hfm 12/5/2010 13:12'!
destroyQuery: aZOOMQuery

	<cdecl: void '_ZOOM_query_destroy@4' (ZOOMQuery) module: 'yaz3'>
	^ self externalCallFailed	! !

!Z3950FFILibrary methodsFor: 'primitives search' stamp: 'hfm 12/5/2010 12:35'!
destroyResultSet
	" Z3950FFILibrary default destroyResultSet
	"
	
	<cdecl: void '_ZOOM_resultset_destroy@4' (void) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives options' stamp: 'hfm 2/25/2009 12:58'!
getConnection: aZoomConnection optionName: aNameString
	" Z3950FFILibrary 
		getConnection: aZoomConnection 
		optionName: ''
	"
	
	<cdecl: char * '_ZOOM_connection_option_get@8' (ZOOMConnection char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives options' stamp: 'hfm 4/25/2009 18:12'!
getOptions: aZOOMOptions optionName: aNameString
	" Z3950FFILibrary getOptions: Z3950FFILibrary createOptions 
					optionName: aNameString "
	
	<cdecl: char * '_ZOOM_options_get@8' (ZOOMOptions char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives packages' stamp: 'hfm 4/25/2009 18:17'!
getPackage: aZOOMPackage optionName: aNameString
	" Answer the option named aNameString in aZOOMPackage "
	
	<cdecl: char * '_ZOOM_package_option_get@8' (ZOOMPackage char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives result set' stamp: 'hfm 2/28/2009 01:13'!
getRecord: aZOOMRecord function: aStringFunction length: anIntegerLength
	" Z3950FFILibrary default
		getRecord: aZOOMResultSet 
		function: 'render' 
	"
	
	<cdecl: char * '_ZOOM_record_get@12' (ZOOMRecord* char* short* ) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives query' stamp: 'hfm 12/5/2010 12:33'!
prefixQuery: aZOOMQuery
	" RPN-queries can be specified in PQF  notation by using the function ZOOM_query_prefix "
	
	<cdecl: short '_ZOOM_query_prefix@8' (ZOOMQuery) module: 'yaz3'>
	^ self externalCallFailed
	! !

!Z3950FFILibrary methodsFor: 'primitives result set' stamp: 'hfm 4/6/2009 16:23'!
resultSetDestroy: aZOOMResultSet
	
	<cdecl: void '_ZOOM_resultset_destroy@4' (ZOOMResultSet) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives result set' stamp: 'hfm 4/4/2009 12:50'!
resultSetOptionGet: aZOOMResultSet optionName: aStringOption
	" 	"
	
	<cdecl: char * '_ZOOM_resultset_option_get@8' (ZOOMResultSet char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives result set' stamp: 'hfm 4/4/2009 12:15'!
resultSetOptionSet: aZOOMResultSet optionName: aStringOption optionValue: aStringValue
	" 	"
	
	<cdecl: void '_ZOOM_resultset_option_set@12' (ZOOMResultSet char * char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives result set' stamp: 'hfm 2/25/2009 19:22'!
resultSetRecord: aZOOMResultSet position: anIntegerPosition
	" Z3950FFILibrary default
		resultSetRecords: aZOOMResultSet 
		position: anInfoString 
	"
	
	<cdecl: ZOOMRecord * '_ZOOM_resultset_record@8' (ZOOMResultSet short) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives result set' stamp: 'hfm 2/25/2009 19:23'!
resultSetRecords: aZOOMResultSet position: anIntegerPosition
	" Z3950FFILibrary default
		resultSetRecords: aZOOMResultSet 
		position: anInfoString 
	"
! !

!Z3950FFILibrary methodsFor: 'primitives result set' stamp: 'hfm 4/6/2009 17:08'!
resultSetRecords: aZOOMResultSet record: aZOOMRecord start: anIntegerStart position: anIntegerPosition
	" Function ZOOM_resultset_records retrieves a number of records from a result set. 
	Parameter start  and count specifies the range of records to be returned. 
	Upon completion array recs[0], ..recs[count-1]  holds record objects for the records. 
	The array of records recs should be allocated prior the call ZOOM_resultset_records. 
	Note that for those records that couldn't be retrieved from the target recs[ ..] is set to NULL. 
	"
	
	<cdecl: void '_ZOOM_resultset_records@16' (ZOOMResultSet ZOOMRecord * short short) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives result set' stamp: 'hfm 4/4/2009 12:17'!
resultSetSize: aZOOMResultSet
	" 	"
	
	<cdecl: short '_ZOOM_resultset_size@4' (ZOOMResultSet) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives scan' stamp: 'hfm 5/2/2009 15:54'!
scan1: aZOOMConnection query: aPQForCQLQueryString
	" A newer and more generic alternative to ZOOM_connection_scan
	which allows to use both CQL and PQF for scan "
	
	<cdecl: ZOOMScanSet '_ZOOM_connection_scan1@8' (ZOOMConnection ZOOMQuery) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives scan' stamp: 'hfm 5/2/2009 15:53'!
scan: aZOOMConnection query: aPQFQueryString
	
	<cdecl: ZOOMScanSet '_ZOOM_connection_scan@8' (ZOOMConnection char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives scan' stamp: 'hfm 5/2/2009 16:11'!
scanSetDestroy: aZOOMScanSet
	" A scan set may be freed by a call to function ZOOM_scanset_destroy "
	
	<cdecl: void '_ZOOM_scanset_destroy@4' (ZOOMScanSet) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives scan' stamp: 'hfm 5/2/2009 16:10'!
scanSetDisplayTerm: aZOOMScanSet position: aPositionNumber occurrences: anOccNumber length: aLengthNumber
	" ZOOM_scanset_display_term is similar to ZOOM_scanset_term except that it returns 
	the display term rather than the raw term. In a few cases, the term is different from display term. 
	Always use the display term for display and the raw term for subsequent scan operations 
	(to get more terms, next scan result, etc). "
	
	<cdecl: char * '_ZOOM_scanset_display_term@16' (ZOOMScanSet short long * short *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives scan' stamp: 'hfm 5/2/2009 16:16'!
scanSetOptionGet: aZOOMScanSet optionName: aStringOption
	" Answer the value of aStringOption option in aZOOMScanSet 	"
	
	<cdecl: char * '_ZOOM_scanset_option_get@8' (ZOOMScanSet char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives scan' stamp: 'hfm 5/2/2009 16:15'!
scanSetOptionSet: aZOOMScanSet optionName: aStringOption optionValue: aStringValue
	" Set aZOOMScanSet option "
	
	<cdecl: void '_ZOOM_scanset_option_set@12' (ZOOMScanSet char * char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives scan' stamp: 'hfm 5/2/2009 16:01'!
scanSetSize: aZOOMScanSet
	" Answer the size of the scan set	 if the scan connection operation was successful, "
	
	<cdecl: short '_ZOOM_scanset_size@4' (ZOOMScanSet) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives scan' stamp: 'hfm 5/2/2009 16:07'!
scanSetTerm: aZOOMScanSet position: aPositionNumber occurrences: anOccNumber length: aLengthNumber
	" To obtain information about a particular scan term, call function ZOOM_scanset_term. 
	This function takes a scan set offset aPositionNumber and returns a pointer to a raw term 
	or NULL if non-present. 
	If present, the anOccNumber and aLengthNumber are set to the number of occurrences 
	and the length of the actual term respectively "
	
	<cdecl: char * '_ZOOM_scanset_term@16' (ZOOMScanSet short long * short *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives search' stamp: 'hfm 2/25/2009 19:02'!
search: aZoomConnection query: aQueryString
	" Z3950FFILibrary 
		search: aZoomConnection 
		query: anInfoString 
	"
	
	<cdecl: ZOOMResultSet '_ZOOM_connection_search@8' (ZOOMConnection ZOOMQuery) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives search' stamp: 'hfm 2/25/2009 19:02'!
searchPqf: aZoomConnection query: aQueryString
	" Z3950FFILibrary 
		searchPqf: aZoomConnection 
		query: anInfoString 
	"
	
	<cdecl: ZOOMResultSet '_ZOOM_connection_search_pqf@8' (ZOOMConnection char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives packages' stamp: 'hfm 4/25/2009 18:22'!
sendPackage: aZOOMPackage type: aValueString
	" Sends the package the via connection specified in #createPackage:options: "

	" The type specifies the actual extended service package type to be sent. 
		Extended Service Common Options
		Option  				Description  																	Default
		package-name  		Extended Service Request package name. Must be specified as part of a request 	none
		user-id  			User ID of Extended Service Package. Is a request option  						none
		function   			Function of package - one of create, delete, modify. Is a request option.   		create
		waitAction   		Wait action for package. 
							Possible values: wait, waitIfPossible, dontWait or dontReturnPackage.   			waitIfPossible
		targetReference   	Target Reference. This is part of the response as returned by the server. 
							Read it after a successful operation.   											none
"
	
	<cdecl: void '_ZOOM_package_send@8' (ZOOMPackage char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives defaults' stamp: 'hfm 8/29/2009 02:59'!
setClientName: aZOOMConnection
	" Private - Set the receiver's client name for the server "

	Z3950FFILibrary default 
		setConnection: aZOOMConnection 
		optionName: 'implementationName' 
		optionValue: 'Squeak/Pharo Smalltalk ZOOM Client v1.0'.! !

!Z3950FFILibrary methodsFor: 'primitives options' stamp: 'hfm 4/25/2009 18:23'!
setConnection: aZoomConnection optionName: aNameString optionValue: aValueString
	
	<cdecl: void '_ZOOM_connection_option_set@12' (ZOOMConnection char * char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives options' stamp: 'hfm 4/25/2009 18:12'!
setOptions: aZOOMOptions optionName: aNameString optionValue: aValueString
	" Z3950FFILibrary setOptions: Z3950FFILibrary createOptions 
					optionName: aNameString 
					optionValue: aValueString "
	
	<cdecl: void '_ZOOM_options_set@12' (ZOOMOptions char * char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives packages' stamp: 'hfm 4/25/2009 18:18'!
setPackage: aZOOMPackage optionName: aNameString optionValue: aValueString
	" Set the option named aNameString in aZOOMPackage with aValueString "
	
	<cdecl: void '_ZOOM_package_option_set@12' (ZOOMPackage char * char *) module: 'yaz3'>
	^ self externalCallFailed! !

!Z3950FFILibrary methodsFor: 'primitives query' stamp: 'hfm 12/5/2010 12:33'!
sortByQuery: aZOOMQuery
	" In addition to a search, a sort criteria may be set. 
	Function ZOOM_query_sortby specifies a sort criteria using 
	the same string notation for sort as offered by the YAZ client "
	
	<cdecl: short '_ZOOM_query_sortby@8' (ZOOMQuery) module: 'yaz3'>
	^ self externalCallFailed
	! !

ExternalStructure subclass: #ZOOMConnection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMConnection class methodsFor: 'field definition' stamp: 'hfm 4/4/2009 13:10'!
fields
	" ZOOMConnection defineFields "
	
	^ #(
		(value	'void *')
		)! !

!ZOOMConnection class methodsFor: 'class initialization' stamp: 'hfm 3/5/2009 19:22'!
initialize

	self defineFields.! !

!ZOOMConnection methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType void asPointerType! !

!ZOOMConnection methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

ExternalStructure subclass: #ZOOMOptions
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMOptions class methodsFor: 'field definition' stamp: 'hfm 5/2/2009 15:55'!
fields
	" self defineFields "	

	^ #( 
		(value 				'void *')
		)! !

!ZOOMOptions class methodsFor: 'class initialization' stamp: 'hfm 3/31/2009 06:26'!
initialize

	self defineFields! !

!ZOOMOptions methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType void asPointerType! !

!ZOOMOptions methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

ExternalStructure subclass: #ZOOMOptionsEntry
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMOptionsEntry class methodsFor: 'field definition' stamp: 'hfm 3/31/2009 06:31'!
fields
	" self defineFields "
	
	^ #(
		(name 	'char *')
		(value	'char *')
		(len     'long')
		(next    'ZOOMOptionsEntry *')
		)
	! !

!ZOOMOptionsEntry class methodsFor: 'class initialization' stamp: 'hfm 3/31/2009 06:30'!
initialize

	self defineFields! !

!ZOOMOptionsEntry methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
len
	"This method was automatically generated"
	^handle signedLongAt: 9! !

!ZOOMOptionsEntry methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
len: anObject
	"This method was automatically generated"
	handle signedLongAt: 9 put: anObject! !

!ZOOMOptionsEntry methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
name
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType char asPointerType! !

!ZOOMOptionsEntry methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
name: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

!ZOOMOptionsEntry methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
next
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 13) type: ExternalType void asPointerType! !

!ZOOMOptionsEntry methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
next: anObject
	"This method was automatically generated"
	handle pointerAt: 13 put: anObject getHandle.! !

!ZOOMOptionsEntry methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 5) type: ExternalType char asPointerType! !

!ZOOMOptionsEntry methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 5 put: anObject getHandle.! !

ExternalStructure subclass: #ZOOMPackage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMPackage class methodsFor: 'field definition' stamp: 'hfm 4/25/2009 17:39'!
fields
	" ZOOMPackage defineFields "
	
	^ #(
		(value	'void *')
		)! !

!ZOOMPackage class methodsFor: 'class initialization' stamp: 'hfm 4/25/2009 17:39'!
initialize
	" self initialize "
	
	self defineFields! !

!ZOOMPackage methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType void asPointerType! !

!ZOOMPackage methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

ExternalStructure subclass: #ZOOMQuery
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMQuery class methodsFor: 'field definition' stamp: 'hfm 5/2/2009 15:57'!
fields
	" self defineFields "
	
	^ #(
		(value		'void *')
		)! !

!ZOOMQuery class methodsFor: 'class initialization' stamp: 'hfm 5/2/2009 15:57'!
initialize
	" self initialize "
	
	self defineFields! !

!ZOOMQuery methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType void asPointerType! !

!ZOOMQuery methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

ExternalStructure subclass: #ZOOMRecord
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMRecord class methodsFor: 'field definition' stamp: 'hfm 3/31/2009 06:08'!
fields
	"  self defineFields  "
	
	^ #(
		(odr 'void')	
		(marcBuffer 'ZOOMWRBUF' )
		(iconvBuffer 'ZOOMWRBUF')				
		(opacBuffer 'ZOOMWRBUF')	
		(zNamePlusRecord 'void *' )				
		(schema 'char*')
		(diagUri 'char*')
		(diagMessage 'char*')
		(diagDetails 'char*')
		(diagSet 'char*')
		)! !

!ZOOMRecord class methodsFor: 'class initialization' stamp: 'hfm 2/25/2009 20:14'!
initialize
	" self initialize "
	
	self defineFields! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
diagDetails
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 17) type: ExternalType char asPointerType! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
diagDetails: anObject
	"This method was automatically generated"
	handle pointerAt: 17 put: anObject getHandle.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
diagMessage
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 13) type: ExternalType char asPointerType! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
diagMessage: anObject
	"This method was automatically generated"
	handle pointerAt: 13 put: anObject getHandle.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
diagSet
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 21) type: ExternalType char asPointerType! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
diagSet: anObject
	"This method was automatically generated"
	handle pointerAt: 21 put: anObject getHandle.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
diagUri
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 9) type: ExternalType char asPointerType! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
diagUri: anObject
	"This method was automatically generated"
	handle pointerAt: 9 put: anObject getHandle.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/31/2009 11:54'!
iconvBuffer
	"This method was automatically generated"
	^ZOOMWRBUF fromHandle: (handle structAt: 9 length: 8)! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/31/2009 11:54'!
iconvBuffer: anObject
	"This method was automatically generated"
	handle structAt: 9 put: anObject getHandle length: 8.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/31/2009 11:54'!
marcBuffer
	"This method was automatically generated"
	^ZOOMWRBUF fromHandle: (handle structAt: 1 length: 8)! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/31/2009 11:54'!
marcBuffer: anObject
	"This method was automatically generated"
	handle structAt: 1 put: anObject getHandle length: 8.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/5/2009 19:20'!
odr
	"This method was automatically generated"
	^ZOOMODR fromHandle: (handle pointerAt: 1)! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/5/2009 19:20'!
odr: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/31/2009 11:54'!
opacBuffer
	"This method was automatically generated"
	^ZOOMWRBUF fromHandle: (handle structAt: 17 length: 8)! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/31/2009 11:54'!
opacBuffer: anObject
	"This method was automatically generated"
	handle structAt: 17 put: anObject getHandle length: 8.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
schema
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 5) type: ExternalType char asPointerType! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
schema: anObject
	"This method was automatically generated"
	handle pointerAt: 5 put: anObject getHandle.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/5/2009 19:45'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType ulong asPointerType! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 3/5/2009 19:45'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
zNamePlusRecord
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType void asPointerType! !

!ZOOMRecord methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
zNamePlusRecord: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

ExternalStructure subclass: #ZOOMRecordType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMRecordType class methodsFor: 'field definition' stamp: 'hfm 11/24/2009 16:41'!
fields
	" self defineFields "
	
	^ #(
		(sortSpecification 		'void *')
		(query					'ZOOMQuery')
		(refCount				'long')
		(size                       'long')
		(step                       'long')
		(piggyBack               'long')
		(setName                 'char *')
		(schema                  'char *')
		(odr                       'void')
		(recordHash              'void')
		(options                   'ZOOMOptions *')
		(connection               'ZOOMConnection')
		(next					'ZOOMResultSet')
		(databaseNames			'char *')
		(numDatabaseNames		'long')
	)! !

!ZOOMRecordType class methodsFor: 'field definition' stamp: 'hfm 2/28/2009 00:20'!
initialize
	self defineFields! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
connection
	"This method was automatically generated"
	^ZOOMConnection fromHandle: (handle structAt: 37 length: 4)! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
connection: anObject
	"This method was automatically generated"
	handle structAt: 37 put: anObject getHandle length: 4.! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
databaseNames
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 41) type: ExternalType char asPointerType! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
databaseNames: anObject
	"This method was automatically generated"
	handle pointerAt: 41 put: anObject getHandle.! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
next
	"This method was automatically generated"
	^ZOOMResultSet fromHandle: (handle structAt: 41 length: 0)! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
next: anObject
	"This method was automatically generated"
	handle structAt: 41 put: anObject getHandle length: 0.! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
numDatabaseNames
	"This method was automatically generated"
	^handle signedLongAt: 45! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
numDatabaseNames: anObject
	"This method was automatically generated"
	handle signedLongAt: 45 put: anObject! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
options
	"This method was automatically generated"
	^ZOOMOptions fromHandle: (handle pointerAt: 33)! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
options: anObject
	"This method was automatically generated"
	handle pointerAt: 33 put: anObject getHandle.! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
piggyBack
	"This method was automatically generated"
	^handle signedLongAt: 21! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
piggyBack: anObject
	"This method was automatically generated"
	handle signedLongAt: 21 put: anObject! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
query
	"This method was automatically generated"
	^ZOOMQuery fromHandle: (handle structAt: 5 length: 4)! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
query: anObject
	"This method was automatically generated"
	handle structAt: 5 put: anObject getHandle length: 4.! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
refCount
	"This method was automatically generated"
	^handle signedLongAt: 9! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
refCount: anObject
	"This method was automatically generated"
	handle signedLongAt: 9 put: anObject! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
schema
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 29) type: ExternalType char asPointerType! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
schema: anObject
	"This method was automatically generated"
	handle pointerAt: 29 put: anObject getHandle.! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
setName
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 25) type: ExternalType char asPointerType! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
setName: anObject
	"This method was automatically generated"
	handle pointerAt: 25 put: anObject getHandle.! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
size
	"This method was automatically generated"
	^handle signedLongAt: 13! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
size: anObject
	"This method was automatically generated"
	handle signedLongAt: 13 put: anObject! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
sortSpecification
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType void asPointerType! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
sortSpecification: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
step
	"This method was automatically generated"
	^handle signedLongAt: 17! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
step: anObject
	"This method was automatically generated"
	handle signedLongAt: 17 put: anObject! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 2/28/2009 00:20'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType char asPointerType! !

!ZOOMRecordType methodsFor: 'accessing' stamp: 'hfm 2/28/2009 00:20'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

ExternalStructure subclass: #ZOOMResultSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMResultSet class methodsFor: 'field definition' stamp: 'hfm 5/2/2009 15:44'!
fields
	" self defineFields "
	
	^ #(
		(value		'void *')
	)! !

!ZOOMResultSet class methodsFor: 'class initialization' stamp: 'hfm 2/25/2009 18:59'!
initialize
	" self initialize "
	
	self defineFields! !

!ZOOMResultSet methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType void asPointerType! !

!ZOOMResultSet methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

ExternalStructure subclass: #ZOOMScanSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-FFI'!

!ZOOMScanSet class methodsFor: 'field definition' stamp: 'hfm 5/2/2009 15:50'!
fields
	" self defineFields "
	
	^ #(
		(value		'void *')
		)! !

!ZOOMScanSet class methodsFor: 'class initialization' stamp: 'hfm 5/2/2009 15:51'!
initialize
	" self initialize "
	
	self defineFields! !

!ZOOMScanSet methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value
	"This method was automatically generated"
	^ExternalData fromHandle: (handle pointerAt: 1) type: ExternalType void asPointerType! !

!ZOOMScanSet methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:27'!
value: anObject
	"This method was automatically generated"
	handle pointerAt: 1 put: anObject getHandle.! !

Object subclass: #Z3950Constants
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Core'!

!Z3950Constants class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 20:03'!
description

	^ 'There is no description for this option value'! !

!Z3950Constants class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:38'!
names
	" Answer a Collection with known database names "
	
	^ self allSubclasses collect: [: each | each id ]
	! !

Z3950Constants subclass: #Z3950DatabaseName
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Databases'!

!Z3950DatabaseName commentStamp: 'hfm 5/4/2009 14:10' prior: 0!
A superclass for common Z39.50 databases!

Z3950DatabaseName subclass: #Z3950Default
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Databases'!

!Z3950Default class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:34'!
id

	^ 'Default'! !

Z3950DatabaseName subclass: #Z3950Innopac
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Databases'!

!Z3950Innopac class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:34'!
id

	^ 'Innopac'! !

Z3950DatabaseName subclass: #Z3950Unicorn
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Databases'!

!Z3950Unicorn class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:34'!
id

	^ 'Unicorn'! !

Z3950DatabaseName subclass: #Z3950Voyager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Databases'!

!Z3950Voyager class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:35'!
id

	^ 'Voyager'! !

Z3950Constants subclass: #Z3950RecordCharsetType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

Z3950RecordCharsetType subclass: #Z3950RecordMARC21Type
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950RecordMARC21Type commentStamp: 'hfm 9/1/2009 20:10' prior: 0!
Most MARC21 records uses the MARC-8 character set encoding!

!Z3950RecordMARC21Type class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 20:11'!
description

	^ 'Most MARC21 records uses the MARC-8 character set encoding'! !

!Z3950RecordMARC21Type class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 20:10'!
id

	^ 'marc8'! !

Z3950Constants subclass: #Z3950RecordSourceType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

Z3950RecordSourceType subclass: #Z3950RecordDatabaseType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950RecordDatabaseType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:54'!
description

	^ 'Databse of record is returned as a string'! !

!Z3950RecordDatabaseType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:54'!
id

	^ 'database'! !

Z3950RecordSourceType subclass: #Z3950RecordOPACType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950RecordOPACType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:54'!
description

	^ 'OPAC for record is returned in XML'! !

!Z3950RecordOPACType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:54'!
id

	^ 'opac'! !

Z3950RecordSourceType subclass: #Z3950RecordRawType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950RecordRawType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:57'!
description

	^ 'The record is returned in the internal YAZ specific format. For GRS-1, Explain and others, the raw data is returned as type Z_External *. For SUTRS and MARCs, the buffer is returned with its length'! !

!Z3950RecordRawType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:55'!
id

	^ 'raw'! !

Z3950RecordSourceType subclass: #Z3950RecordRenderType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950RecordRenderType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:57'!
description

	^ 'The record is returned in a display friendly format.'! !

!Z3950RecordRenderType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:57'!
id

	^ 'render'! !

Z3950RecordSourceType subclass: #Z3950RecordSchemaType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950RecordSchemaType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:58'!
description

	^ 'The schema of the record is returned as a String'! !

!Z3950RecordSchemaType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:58'!
id

	^ 'schema'! !

Z3950RecordSourceType subclass: #Z3950RecordSyntaxType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950RecordSyntaxType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:59'!
description

	^ 'The transfer syntax of the record is returned as a String containing the symbolic name of the record syntax, e.g. Usmarc'! !

!Z3950RecordSyntaxType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:58'!
id

	^ 'syntax'! !

Z3950RecordSourceType subclass: #Z3950RecordXMLType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950RecordXMLType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 20:01'!
description

	^ 'The record is returned in XML if possible. SRU and Z39.50 records with transfer syntax XML are returned verbatim. MARC records are returned in MARCXML (converted from ISO2709 to MARCXML by YAZ). GRS-1 and OPAC records are not supported in this form'! !

!Z3950RecordXMLType class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 19:59'!
id

	^ 'xml'! !

Z3950Constants subclass: #Z3950RecordTypeFormat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-RecordFormats'!

Z3950RecordTypeFormat subclass: #Z3950DanMarc
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-RecordFormats'!

!Z3950DanMarc class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:39'!
id

	^ 'DANMARC'! !

Z3950RecordTypeFormat subclass: #Z3950Marc21
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-RecordFormats'!

!Z3950Marc21 class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:39'!
id

	^ 'MARC21'! !

Z3950RecordTypeFormat subclass: #Z3950Sutrs
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-RecordFormats'!

!Z3950Sutrs class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:39'!
id

	^ 'SUTRS'! !

Object subclass: #Z3950Object
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Core'!

Z3950Object subclass: #Z3950AttributeCollection
	instanceVariableNames: 'attributeSets'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

!Z3950AttributeCollection methodsFor: 'composition' stamp: 'hfm 10/19/2009 20:07'!
, aZ3950AttributeSet
	"Return the concatenation of the receiver and aZ3950AttributeSet."

	^ self add: aZ3950AttributeSet
! !

!Z3950AttributeCollection methodsFor: 'composition' stamp: 'hfm 10/20/2009 01:41'!
add: aZ39AttributeSet
	" Include newObject as one of the receiver's elements "
	
	attributeSets := attributeSets copyWith: aZ39AttributeSet.! !

!Z3950AttributeCollection methodsFor: 'accessing' stamp: 'hfm 10/20/2009 02:26'!
allButFirst
	"Answer a copy of the receiver containing all but the first
	element. Raise an error if there are not enough elements."
	
	^ attributeSets allButFirst! !

!Z3950AttributeCollection methodsFor: 'converting' stamp: 'hfm 10/20/2009 02:23'!
asPQFAttributeList

	^ self! !

!Z3950AttributeCollection methodsFor: 'accessing' stamp: 'hfm 10/20/2009 02:25'!
first
	" Answer the first attribute set of the receiver "
	
	^ attributeSets at: 1! !

!Z3950AttributeCollection methodsFor: 'initialize-release' stamp: 'hfm 10/20/2009 01:41'!
initialize

	super initialize.
	attributeSets := Array new.! !

!Z3950AttributeCollection methodsFor: 'accessing' stamp: 'hfm 10/20/2009 02:25'!
size
	" Answer how many elements the receiver contains. "
	
	^ attributeSets size! !

Z3950Object subclass: #Z3950AttributeSet
	instanceVariableNames: 'attributeValue'
	classVariableNames: 'AttributeMap'
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

Z3950AttributeSet class
	instanceVariableNames: 'attributeMap'!

!Z3950AttributeSet commentStamp: 'hfm 10/19/2009 20:03' prior: 0!
An abstract attribute in an attribute list. Final subclasses represents a set of attributes (use, relation, position, etc) which will be instantiated for a specific search condition.

attributeValue 		<String>		The configured value (search condition) of a particular attribute!

Z3950AttributeSet class
	instanceVariableNames: 'attributeMap'!

!Z3950AttributeSet class methodsFor: 'accessing public' stamp: 'hfm 10/20/2009 02:58'!
att: anObject
	" Answer a new instance of the receiver for anObject search value type "
	
	( self attributeMap includesKey: anObject asString )
		ifFalse: [ self error: 'Invalid search value: ' , anObject asString  ].
	^ self new attributeValue: anObject asString.! !

!Z3950AttributeSet class methodsFor: 'accessing' stamp: 'hfm 10/20/2009 02:08'!
attributeMap

	^ attributeMap
		ifNil: [ attributeMap := Dictionary new ]! !

!Z3950AttributeSet class methodsFor: 'accessing' stamp: 'hfm 10/20/2009 02:07'!
attributeMap: anObject
	attributeMap := anObject! !

!Z3950AttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/19/2009 19:12'!
identifier
	" Answer a String with the identifier for this attribute set "
	
	self subclassResponsibility! !

!Z3950AttributeSet class methodsFor: 'class initialization' stamp: 'hfm 10/20/2009 01:52'!
initialize
	" Private - Initialize the attribute mappings "
	
	" self initialize "
	
	super initialize.
	self allSubclassesDo: [: cls |
		cls subclasses isEmpty
			ifTrue: [ cls createAttributeMap ]
	].! !

!Z3950AttributeSet methodsFor: 'accessing public' stamp: 'hfm 10/20/2009 02:15'!
, aZ3950AttributeSet
	" Return the concatenation of the receiver and aZ3950AttributeSet."
	
	^ Z3950AttributeCollection new
		add: self;
		add: aZ3950AttributeSet! !

!Z3950AttributeSet methodsFor: 'accessing public' stamp: 'hfm 10/20/2009 03:05'!
asPQFAttributeList

	^ Array with: self! !

!Z3950AttributeSet methodsFor: 'accessing public' stamp: 'hfm 10/19/2009 19:52'!
asString
	" Answer a String representation of an attribute list
	for the receiver and anObject search value type "

	^ String streamContents: [: s |
		s nextPutAll: self class identifier;
			nextPut: $=;
			nextPutAll: self attributeValue ]! !

!Z3950AttributeSet methodsFor: 'accessing private' stamp: 'hfm 10/19/2009 19:50'!
attributeValue
	^ attributeValue! !

!Z3950AttributeSet methodsFor: 'accessing private' stamp: 'hfm 10/19/2009 19:50'!
attributeValue: anObject
	attributeValue := anObject! !

Z3950AttributeSet subclass: #Z3950NonUseAttributeSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

Z3950NonUseAttributeSet subclass: #Z3950CompletenessAttributeSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

!Z3950CompletenessAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/19/2009 05:25'!
attributes
	" Answer a String with the Relation Attributes
	with a description "

	^ '1;Incomplete subfield (default)
2;Complete subfield
3;Complete field'! !

!Z3950CompletenessAttributeSet class methodsFor: 'accessing public' stamp: 'hfm 10/19/2009 05:24'!
description
	" Answer a String with a description for the
	receiver's use "
	
	^ 'The completeness attribute is used to spacify that a given search term o term list is either part of the terms of a given index/field (Incomplete subfield (1)), or is what literally is found in the entire field''s index (Complete field (3))'! !

!Z3950CompletenessAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/18/2009 21:53'!
identifier
	" Answer a String with the identifier for this attribute set "
	
	^ '6'! !

!Z3950NonUseAttributeSet class methodsFor: 'accessing' stamp: 'hfm 10/19/2009 05:42'!
attributeClassFor: aString

	^ ( aString includes: 'default')
		ifFalse: [ Z3950Attribute ]
		ifTrue: [ Z3950DefaultAttribute ].! !

!Z3950NonUseAttributeSet class methodsFor: 'accessing' stamp: 'hfm 10/20/2009 02:49'!
createAttributeMap
	" Private -  "
	| parser |
	
	attributeMap := Dictionary new.	
	parser := self parserFor: self attributes.
	parser rowsDo: [: row | 
		| attribute |
		attribute := ( self attributeClassFor: row second ) new
						attributeNumber: row second;
						attributeName: row first.
		self attributeMap add: attribute ].
	! !

!Z3950NonUseAttributeSet class methodsFor: 'accessing' stamp: 'hfm 6/12/2010 02:38'!
parserFor: aCollection
	" Answer a parser for parsing the attribute set information "

	^ ( STextParser on: aCollection ) delimiter: $;! !

Z3950NonUseAttributeSet subclass: #Z3950PositionAttributeSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

!Z3950PositionAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/19/2009 05:26'!
attributes
	" Answer a String with the Relation Attributes
	with a description "

	^ '1;First in field
2;First in subfield
3;Any position in field (default)'! !

!Z3950PositionAttributeSet class methodsFor: 'accessing public' stamp: 'hfm 10/19/2009 05:07'!
description
	" Answer a String with a description for the
	receiver's use "
	
	^ 'The position attribute specifies the location of the search term within the field or subfield in which it appears'! !

!Z3950PositionAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/18/2009 21:54'!
identifier
	" Answer a String with the identifier for this attribute set "
	
	^ '3'! !

Z3950NonUseAttributeSet subclass: #Z3950RelationAttributeSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

!Z3950RelationAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/19/2009 05:26'!
attributes
	" Answer a String with the Relation Attributes
	with a description "

	^ '1;< Less than
2;<= Less than or equal
3;= Equal (default)
4;>= Greater or equal
5;> Greater
6;<> Not equal
100;Phonetic
101;Stem
102;Relevance
103;Always Matches'! !

!Z3950RelationAttributeSet class methodsFor: 'accessing public' stamp: 'hfm 10/19/2009 05:09'!
description
	" Answer a String with a description for the
	receiver's use "
	
	^ 'Relation attributes describe the relationship of the access point (left side of the relation) to the search term as qualified by the attributes (right side of the relation), e.g., Date-publication <= 1976'! !

!Z3950RelationAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/18/2009 21:54'!
identifier
	" Answer a String with the identifier for this attribute set "
	
	^ '2'! !

Z3950NonUseAttributeSet subclass: #Z3950StructureAttributeSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

!Z3950StructureAttributeSet commentStamp: 'hfm 10/20/2009 02:40' prior: 0!
Z3950StructureAttributeSet attributeMap explore.!

!Z3950StructureAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/19/2009 05:27'!
attributes
	" Answer a String with the Structure Attributes
	with a description "

	^ '1;Phrase (default)
2;Word
3;Key
4;Year
5;Date (normalized)
6;Word list
100;Date (un-normalized)
101;Name (normalized)
102;Name (un-normalized)
103;Structure
104;Urx
105;Free-form-text
106;Document-text
107;Local-number
108;String
109;Numeric string'! !

!Z3950StructureAttributeSet class methodsFor: 'accessing public' stamp: 'hfm 10/19/2009 05:06'!
description
	" Answer a String with a description for the
	receiver's use "
	
	^ 'The structure attribute specifies the type of search term. This causes the search to be mapped on different Zebra internal indexes, which must have been defined at index time'! !

!Z3950StructureAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/18/2009 21:55'!
identifier
	" Answer a String with the identifier for this attribute set "
	
	^ '4'! !

Z3950NonUseAttributeSet subclass: #Z3950TruncationAttributeSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

!Z3950TruncationAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/19/2009 05:21'!
attributes
	" Answer a String with the Relation Attributes
	with a description "

	^ '1;Right truncation
2;Left truncation
3;Left and right truncation
100;Do not truncate (default)
101;Process # in search term
102;RegExpr-1
103;RegExpr-2'! !

!Z3950TruncationAttributeSet class methodsFor: 'accessing public' stamp: 'hfm 10/19/2009 05:22'!
description
	" Answer a String with a description for the
	receiver's use "
	
	^ 'The truncation attribute specifies whether variations of one or more characters are allowed between search term and hit terms, or not. Using non-default truncation attributes wil broaden the document hit set of a search query'! !

!Z3950TruncationAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/18/2009 21:55'!
identifier
	" Answer a String with the identifier for this attribute set "
	
	^ '5'! !

Z3950AttributeSet subclass: #Z3950UseAttributeSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

Z3950UseAttributeSet subclass: #Z3950Bib1UseAttributeSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Attributes'!

!Z3950Bib1UseAttributeSet commentStamp: 'hfm 10/20/2009 02:50' prior: 0!
Z3950Bib1UseAttributeSet attributeMap explore!

!Z3950Bib1UseAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/18/2009 22:20'!
attributes

	^ '# $Id: bib1.att,v 1.2 2006/05/19 23:45:29 adam Exp $
# Bib-1 Attribute Set
name bib1
reference Bib-1

1               Personal-name
2               Corporate-name
3               Conference-name
4               Title
5               Title-series
6               Title-uniform
7               ISBN
8               ISSN
9               LC-card-number
10              BNB-card-number
11              BGF-number
12              Local-number
13              Dewey-classification
14              UDC-classification
15              Bliss-classification
16              LC-call-number
17              NLM-call-number
18              NAL-call-number
19              MOS-call-number
20              Local-classification
21              Subject-heading
22              Subject-Rameau
23              BDI-index-subject
24              INSPEC-subject
25              MESH-subject
26              PA-subject
27              LC-subject-heading
28              RVM-subject-heading
29              Local-subject-index
30              Date
31              Date-of-publication
32              Date-of-acquisition
33              Title-key
34              Title-collective
35              Title-parallel
36              Title-cover
37              Title-added-title-page
38              Title-caption
39              Title-running
40              Title-spine
41              Title-other-variant
42              Title-former
43              Title-abbreviated
44              Title-expanded
45              Subject-precis
46              Subject-rswk
47              Subject-subdivision
48              Number-natl-biblio
49              Number-legal-deposit
50              Number-govt-pub
51              Number-music-publisher
52              Number-db
53              Number-local-call
54              Code-language
55              Code-geographic
56              Code-institution
57              Name-and-title
58              Name-geographic
59              Place-publication
60              CODEN
61              Microform-generation
62              Abstract
63              Note
1000            Author-title
1001            Record-type
1002            Name
1003            Author
1004            Author-name-personal
1005            Author-name-corporate
1006            Author-name-conference
1007            Identifier-standard
1008            Subject-LC-childrens
1009            Subject-name-personal
1010            Body-of-text
1011            Date/time-added-to-db
1012            Date/time-last-modified
1013            Authority/format-id
1014            Concept-text
1015            Concept-reference
1016            Any
1017            Server-choice
1018            Publisher
1019            Record-source
1020            Editor
1021            Bib-level
1022            Geographic-class
1023            Indexed-by
1024            Map-scale
1025            Music-key
1026            Related-periodical
1027            Report-number
1028            Stock-number
1030            Thematic-number
1031            Material-type
1032            Doc-id
1033            Host-item
1034            Content-type
1035            Anywhere
1036            Author-Title-Subject'	! !

!Z3950Bib1UseAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 6/12/2010 02:37'!
createAttributeMap
	" Private -  "
	| parser |
	
	attributeMap := Dictionary new: 100.
	parser := ( STextParser on: self attributes )
						ignoreHeadersCount: 4;
						delimiter: Character space.
	parser rowsDo: [: row | 
		self attributeMap 
				at: row first
				put: row second ].
	! !

!Z3950Bib1UseAttributeSet class methodsFor: 'accessing public' stamp: 'hfm 10/19/2009 05:10'!
description
	" Answer a String with a description for the
	receiver's use "
	
	^ 'A use attribute specifies an access point for any atomic query'! !

!Z3950Bib1UseAttributeSet class methodsFor: 'accessing private' stamp: 'hfm 10/18/2009 21:53'!
identifier
	" Answer a String with the identifier for this attribute set "
	
	^ '1'! !

Z3950Object subclass: #Z3950Client
	instanceVariableNames: 'connection connectionOptions resultSetOptions typeFormOptions history'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Core'!

!Z3950Client commentStamp: 'hfm 9/2/2009 00:22' prior: 0!
A facade to the connection, queries and options. You should use this object to make queries.

connection		<Z3950Connection>		A connection object to a Z39.50 server
options 			<Collection>				Options to apply in the connection, results sets or type form
history 			<Collection>				Queries or operations performed against the connection!

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/2/2009 00:22'!
connection

	^ connection
		ifNil: [ connection := Z3950Connection newFrom: self ]! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 21:40'!
connection: anObject
	connection := anObject! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 23:28'!
connectionOptions

	^ connectionOptions
		ifNil: [ connectionOptions := self defaultConnectionOptions ]! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 21:59'!
connectionOptions: anObject
	connectionOptions := anObject! !

!Z3950Client methodsFor: 'defaults' stamp: 'hfm 9/2/2009 18:19'!
defaultConnectionOptions
	" Answer a 'safe' set of connection options "

	^ Z3950ConnectionOptions newWithDefaults! !

!Z3950Client methodsFor: 'defaults' stamp: 'hfm 9/1/2009 23:28'!
defaultResultSetOptions
	" Answer a 'safe' set of result set options "

	^ Z3950ResultSetOptions new
		optionAt: 'preferredRecordSyntax' put: 'USMARC';
		yourself		! !

!Z3950Client methodsFor: 'defaults' stamp: 'hfm 9/2/2009 17:38'!
defaultTypeFormOptions
	" Answer a String with a 'safe' set of type form options
	for displaying results "

	^ Z3950TypeFormOptions newWithDefaults asString
! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 21:40'!
history
	^ history! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 21:40'!
history: anObject
	history := anObject! !

!Z3950Client methodsFor: 'accessing connection' stamp: 'hfm 9/1/2009 21:56'!
hostName
	" Answer a String representing the 
	remote host name to connect "

	^ self connectionOptions hostName! !

!Z3950Client methodsFor: 'defaults' stamp: 'hfm 6/12/2010 18:00'!
options

	^ Dictionary new
		addAll: self connectionOptions options;
		addAll: self resultSetOptions options;
		yourself! !

!Z3950Client methodsFor: 'accessing connection' stamp: 'hfm 9/1/2009 21:55'!
port
	" Answer a Number representing the port
	number to connect in a server "

	^ self connectionOptions port asNumber! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 12/5/2010 14:09'!
query: aPQFString
	" Answer a Collection of results "
	
	^ ( self validate: aPQFString pqfSyntax )
		ifTrue: [ self connection query: aPQFString from: self ]
	! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 23:29'!
resultSetOptions

	^ resultSetOptions
		ifNil: [ resultSetOptions := self defaultResultSetOptions ]! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 21:59'!
resultSetOptions: anObject
	resultSetOptions := anObject! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 6/12/2010 15:54'!
server: aServerObjectOrSymbol
	" Set the receiver's server "

	connectionOptions := Z3950ConnectionOptions newWith: aServerObjectOrSymbol.
	resultSetOptions := Z3950ResultSetOptions newWith: aServerObjectOrSymbol! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 23:30'!
typeFormOptions

	^ typeFormOptions
		ifNil: [ typeFormOptions := self defaultTypeFormOptions ]! !

!Z3950Client methodsFor: 'accessing' stamp: 'hfm 9/1/2009 21:59'!
typeFormOptions: anObject
	typeFormOptions := anObject! !

!Z3950Client methodsFor: 'testing' stamp: 'hfm 3/29/2010 04:02'!
validate: aPQFString
	" Answer <true> is aPQFString is a valid PQF "
	
	" self validator ..."
	| yazLib parser message messageOffset result |
	
	yazLib := YAZPQFFFILibrary default.
	parser := yazLib createParser.
	
	result := ( yazLib parseQuery: parser
			odr: YAZODRFFILibrary default createForEncoding
			query: aPQFString ).
	
	message := YAZErrorMessage new.
	messageOffset := YAZOffsetMessage new value: 0.
	yazLib getError: parser
		message: message
		offset: messageOffset.
	^ message value fromCString = 'no error'! !

Z3950Object subclass: #Z3950Connection
	instanceVariableNames: 'client'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Core'!

!Z3950Connection commentStamp: 'hfm 9/2/2009 00:24' prior: 0!
This is the an interface to a Z39.50 connection, uses directly the ZOOM FFI binding.!

!Z3950Connection class methodsFor: 'instance creation' stamp: 'hfm 9/2/2009 00:23'!
newFrom: aZ3950Client

	^ super new initializeWith: aZ3950Client! !

!Z3950Connection methodsFor: 'accessing' stamp: 'hfm 3/29/2010 04:06'!
client
	^ client! !

!Z3950Connection methodsFor: 'private' stamp: 'hfm 6/12/2010 19:21'!
configureConnectionOptions
	" Answer a new connected ZOOMConnection 
	to the receiver's server "
	
	| zConn |

	zConn := self library 
				createConnectionTo: self client hostName
				port: self client port.
	self library createOptions.
	self client options associationsDo: [: optionAssoc |
		| config |
		( config := optionAssoc value ) isDefault  " option was set "
			ifFalse: [
				self library 
					setConnection: zConn 
					optionName: optionAssoc key
					optionValue: config value ]
		].	
	^ zConn! !

!Z3950Connection methodsFor: 'initialize-release' stamp: 'hfm 9/2/2009 00:24'!
initializeWith: aZ3950Client

	client := aZ3950Client! !

!Z3950Connection methodsFor: 'private' stamp: 'hfm 9/1/2009 22:02'!
library

	^ Z3950FFILibrary default ! !

!Z3950Connection methodsFor: 'accessing' stamp: 'hfm 12/5/2010 14:10'!
query: aPQFQueryString
	" Answer a Collection with the result of aPQFQueryString query in the
	receiver's connection. If no server was configured then use a random server "

	| zConn results |

	zConn := self configureConnectionOptions.
	results := self library 
				searchPqf: zConn 
				query: aPQFQueryString pqfSyntax.
	^ self scanResultSet: results.! !

!Z3950Connection methodsFor: 'accessing' stamp: 'hfm 6/14/2010 00:18'!
query: aPQFQueryString from: aZ3950Client
	" Answer a Collection with the result of aPQFQueryString query in the
	receiver's connection. If no server was configured then use a random server "

	client := aZ3950Client.
	^ self query: aPQFQueryString! !

!Z3950Connection methodsFor: 'private' stamp: 'hfm 9/2/2009 17:37'!
scanResultSet: aZOOMResultSet
	" Answer a Collection with all records
	found in aZOOMResultSet "

	| resultSetSize records |

	(resultSetSize := self library resultSetSize: aZOOMResultSet) = 0
		ifTrue: [ ^ 'No records found for your query' translated ].
	records := Array new: resultSetSize.
	" First record has position zero "
	0 to: resultSetSize - 1 do: [: pos | 
		| record |
		record := self library resultSetRecord: aZOOMResultSet position: pos.
		records 
			at: pos + 1 
			put: ( self library
					getRecord: record 
					function: self client typeFormOptions 
					length: nil ).	
	 ].
	^ records.! !

Z3950Object subclass: #Z3950Option
	instanceVariableNames: 'default description values value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950Option commentStamp: 'hfm 9/2/2009 00:03' prior: 0!
This is a particular Z39.50 option

description 			<String>		A description of the option
default 				<Object>		The default option value as of YAZ User's Guide and Reference
values 				<Collection>	Possible values for the receiver, default value could be changed at run time.!

!Z3950Option class methodsFor: 'instance creation' stamp: 'hfm 6/12/2010 18:08'!
default: anObject description: aString
	" Answer a new instance of the receiver
	configured with anObject as default value
	and aString as description "
	
	^ super new
		default: anObject;
		description: aString! !

!Z3950Option methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:08'!
default
	^ default! !

!Z3950Option methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:08'!
default: anObject
	default := anObject! !

!Z3950Option methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:09'!
description
	^ description! !

!Z3950Option methodsFor: 'accessing' stamp: 'hfm 9/1/2009 18:09'!
description: anObject 
	description := anObject! !

!Z3950Option methodsFor: 'testing' stamp: 'hfm 6/12/2010 18:09'!
isDefault
	" Answer <true> if receiver has not been configured "

	^ self value isNil or: [ self value = self default ]! !

!Z3950Option methodsFor: 'printing' stamp: 'hfm 6/13/2010 22:14'!
printOn: aStream
	" Private - See superimplementor's comment "
	
	super printOn: aStream.
	aStream
		cr;
		nextPutAll: 'Default : ' translated;
		nextPutAll: default asString;
		cr;
		nextPutAll: 'Current : '; 
		nextPutAll: value asString;
		cr;
		nextPutAll: 'Description : '; 		
		nextPutAll: description asString! !

!Z3950Option methodsFor: 'accessing' stamp: 'hfm 9/2/2009 00:17'!
value

	^ value! !

!Z3950Option methodsFor: 'accessing' stamp: 'hfm 9/2/2009 00:16'!
value: anObject

	value := anObject! !

!Z3950Option methodsFor: 'accessing' stamp: 'hfm 9/2/2009 00:03'!
values
	^ values! !

!Z3950Option methodsFor: 'accessing' stamp: 'hfm 9/2/2009 00:03'!
values: anObject
	values := anObject! !

Z3950Object subclass: #Z3950Options
	instanceVariableNames: 'options'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

Z3950Options class
	instanceVariableNames: 'optionsMap'!

!Z3950Options commentStamp: 'hfm 6/14/2010 00:49' prior: 0!
Z39.50 Abstract class for supporting object with configuration options

1 				= true
1024 			= 1Mbyte!

Z3950Options class
	instanceVariableNames: 'optionsMap'!

Z3950Options subclass: #Z3950ConnectionOptions
	instanceVariableNames: 'serverObject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950ConnectionOptions commentStamp: 'hfm 9/1/2009 15:58' prior: 0!
Option map for Z39.50 connections!

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:18'!
defaultAsync

	^ Z3950Option
		default: 0 " false "
		description: 'If true, the connection operates in asynchronous operation which means that all calls are non-blocking except ZOOM_event'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:18'!
defaultCharset

	^ Z3950Option
		default: nil " ? "
		description: 'Character set for negotiation'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 3/29/2010 03:34'!
defaultDatabaseName

	^ (Z3950Option
		default: 'Default'
		description: 'One or more database names separated by character plus (+), which be used by subsequent search requests on this Connection')
		values: Z3950DatabaseName names! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 6/12/2010 16:01'!
defaultDatabaseName: aValue

	^ (Z3950Option
		default: 'Default'
		description: 'One or more database names separated by character plus (+), which be used by subsequent search requests on this Connection')
		values: Z3950DatabaseName names;
		value: aValue;
		yourself! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 6/12/2010 15:44'!
defaultHost

	^ Z3950Option
		default: 'localhost'
		description: 'Target host. This setting is "read-only". It''s automatically set internally when connecting to a target.'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:23'!
defaultInitOptPresent

	^ Z3950Option
		default: nil
		description: 'After a succesful Init, these options may be interrogated to discover whether the server claims to support the specified operations'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:23'!
defaultInitOptSearch

	^ Z3950Option
		default: nil
		description: 'After a succesful Init, these options may be interrogated to discover whether the server claims to support the specified operations'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:18'!
defaultLang

	^ Z3950Option
		default: nil " ? "
		description: 'Language for negotiation'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:18'!
defaultLargeSetLowerBound

	^ Z3950Option
		default: 1
		description: 'If hits is greater than this value, the target will return no records'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 3/29/2010 03:33'!
defaultMaximumRecordSize

	^ Z3950Option
		default: 1024
		description: 'Maximum size of single record'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:21'!
defaultMediumSetElementSetName

	^ Z3950Option
		default: nil " ? "
		description: 'The element set name to be used for medium-sized result sets'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:22'!
defaultMediumSetPresentNumber

	^ Z3950Option
		default: 0
		description: 'This value represents the number of records to be returned as part of a search when hits is less than or equal to large set lower bound and if hits is greater than small set upper bound'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:19'!
defaultPiggyBack

	^ Z3950Option
		default: 1
		description: 'True if piggyback sould be used in searches; false if not'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 3/29/2010 03:34'!
defaultPreferredMessageSize

	^ Z3950Option
		default: 1024
		description: 'Maximum size of multiple records'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:19'!
defaultServerImplementationId

	^ Z3950Option
		default: nil " ? "
		description: 'Implementation ID of server'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:19'!
defaultServerImplementationVersion

	^ Z3950Option
		default: nil " ? "
		description: 'Implementation Version of server'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:20'!
defaultSmallSetElementSetName

	^ Z3950Option
		default: nil " ? "
		description: 'The element set name to be used for small result sets'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:19'!
defaultSmallSetUpperBound

	^ Z3950Option
		default: 0
		description: 'If hits is less than or equal to this value, then target will return all records using small element set name'! !

!Z3950ConnectionOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:19'!
defaultTargetImplementationName

	^ Z3950Option
		default: nil " ? "
		description: 'Implementation Name of server'! !

!Z3950ConnectionOptions class methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:14'!
options

	^ Dictionary new
	"	at: 'user' put: nil;
		at: 'group' put: nil;
		at: 'password' put: nil;
		at: 'proxy' put: nil;"
		at: 'host' put: self defaultHost;
		at: 'async' put: self defaultAsync;
		at: 'maximumRecordSize' put: self defaultMaximumRecordSize;
		at: 'preferredMessageSize' put: self defaultPreferredMessageSize;
		at: 'lang' put: self defaultLang;
		at: 'charset' put: self defaultCharset;
		at: 'serverImplementationId' put: self defaultServerImplementationId;
		at: 'targetImplementationName' put: self defaultTargetImplementationName;
		at: 'serverImplementationVersion' put: self defaultServerImplementationVersion;
		at: 'databaseName' put: self defaultDatabaseName;
		at: 'piggyBack' put: self defaultPiggyBack; " true "
		at: 'smallSetUpperBound' put: self defaultSmallSetUpperBound;
		at: 'largeSetLowerBound' put: self defaultLargeSetLowerBound;
		at: 'mediumSetPresentNumber' put: self defaultMediumSetPresentNumber;
		at: 'smallSetElementSetName' put: self defaultSmallSetElementSetName;
		at: 'mediumSetElementSetName' put: self defaultMediumSetElementSetName;
		at: 'init_opt_search' put: self defaultInitOptSearch; 
		at: 'init_opt_present' put: self defaultInitOptPresent;
		yourself " .... "! !

!Z3950ConnectionOptions methodsFor: 'accessing' stamp: 'hfm 6/12/2010 15:45'!
hostName 

	^ serverObject isNil
		ifFalse: [ serverObject hostName ]
		ifTrue: [ ( self optionAt: 'host' put: self class defaultHost ) value ]
! !

!Z3950ConnectionOptions methodsFor: 'initialize-release' stamp: 'hfm 6/12/2010 16:01'!
initializeWith: anObject
	" Set the receiver's server "

	serverObject := anObject asZ3950Server.
	options := self class options.
	self optionAt: 'databaseName' put:  ( self class defaultDatabaseName: serverObject databases )! !

!Z3950ConnectionOptions methodsFor: 'initialize-release' stamp: 'hfm 9/2/2009 18:24'!
initializeWithDefaults

	options :=  Z3950ServerRepository new anyOne
	" serverAt: aString "! !

!Z3950ConnectionOptions methodsFor: 'accessing' stamp: 'hfm 6/12/2010 15:46'!
port 

	^ serverObject port! !

!Z3950Options class methodsFor: 'instance creation' stamp: 'hfm 6/12/2010 15:53'!
newWith: anObject
	" Answer a new instance with anObject as the receiver's server "

	| newInstance |

	newInstance := super new.
	self optionsMap addAll: self options.
	newInstance initializeWith: anObject.
	^ newInstance! !

!Z3950Options class methodsFor: 'instance creation' stamp: 'hfm 11/24/2009 16:23'!
newWithDefaults
	" Answer a new instance of the receiver
	with default options configured "

	| newInstance |

	newInstance := super new.
	self optionsMap addAll: self options.
	newInstance initializeWithDefaults.
	^ newInstance! !

!Z3950Options class methodsFor: 'pool variables' stamp: 'hfm 11/24/2009 16:18'!
optionsMap

	^ optionsMap	
		ifNil: [ optionsMap := IdentityDictionary new ]
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 21:55'!
optionAt: anOptionString
	" Answer the Z3950Option receiver's value at anOptionString "

	^ self options 
		at: anOptionString asString
		ifAbsent: [ ]
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 21:55'!
optionAt: anOptionString ifAbsent: aBlock
	" Answer the receiver's value at anOptionString,
	if none found, evaluate aBlock "

	^  self options 
		at: anOptionString asString
		ifAbsent: aBlock
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 21:55'!
optionAt: anOptionString ifAbsentPut: aBlock
	" Answer the receiver's value at anOptionString,
	if none found,add the result of evaluating aBlock "

	^  self options 
		at: anOptionString asString
		ifAbsentPut: aBlock
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 21:56'!
optionAt: anOptionString ifPresent: aBlock
	" Answer the receiver's value at anOptionString,
	if found,evaluate aBlock "

	^  self options 
		at: anOptionString asString
		ifPresent: aBlock
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 21:56'!
optionAt: anOptionString put: aValue
	" Add aValue into the receiver
	at anOptionString "

	^  self options 
		at: anOptionString asString
		put: aValue
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:26'!
optionDefaultAt: anOptionString
	" Answer the Z3950Option receiver's value at anOptionString "

	^ ( self optionAt: anOptionString ) default
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:27'!
optionDefaultAt: anOptionString ifAbsent: aBlock
	" Answer the receiver's value at anOptionString,
	if none found, evaluate aBlock "

	^ ( self optionAt: anOptionString ifAbsent: aBlock ) default
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:23'!
optionValueAt: anOptionString
	" Answer the Z3950Option receiver's value at anOptionString "

	^ ( self optionAt: anOptionString ) value
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:24'!
optionValueAt: anOptionString ifAbsent: aBlock
	" Answer the receiver's value at anOptionString,
	if none found, evaluate aBlock "

	^ ( self optionAt: anOptionString ifAbsent: aBlock ) value
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:24'!
optionValueAt: anOptionString ifAbsentPut: aBlock
	" Answer the receiver's value at anOptionString,
	if none found,add the result of evaluating aBlock "

	^ ( self optionAt: anOptionString ifAbsentPut: aBlock ) value
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 18:25'!
optionValueAt: anOptionString ifPresent: aBlock
	" Answer the receiver's value at anOptionString,
	if found,evaluate aBlock "

	^ ( self optionAt: anOptionString ifPresent: aBlock ) value
		! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 6/12/2010 21:55'!
options
	^ options
		ifNil: [ options := Dictionary new ]! !

!Z3950Options methodsFor: 'accessing' stamp: 'hfm 3/29/2010 04:10'!
options: anObject
	options := anObject! !

Z3950Options subclass: #Z3950Query
	instanceVariableNames: 'querySelector pqfTranslator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Core'!

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 01:20'!
author

	^ self optionAt: 'author' ifAbsent: [ '' ]! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 00:46'!
author: anObject
	" Set the receiver's query author "
	
	self querySelector: #authorFromString:.
	self optionAt: 'author' put: anObject.! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 00:42'!
pqfSyntax
	" Answer a String suitable for sending the query to a server "

	^ self pqfTranslator 
			perform: self querySelector 
			with: self querySubject
	! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 00:51'!
pqfTranslator

	^ pqfTranslator
		ifNil: [ pqfTranslator := PQFTranslator new ]! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 00:47'!
pqfTranslator: anObject
	pqfTranslator := anObject! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 00:42'!
querySelector
	^ querySelector! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 00:42'!
querySelector: anObject
	querySelector := anObject! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 01:06'!
querySubject
	" Private - Answer a String. This is for queries with a single term 
	(ToDo: Combined queries ) "
	
	^ self options 
		detect: [ : assoc | assoc value isNil not ]
		ifNone: [ self error: 'Empty query' translated ]
	! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 01:20'!
title

	^ self optionAt: 'title' ifAbsent: [ '' ]! !

!Z3950Query methodsFor: 'accessing' stamp: 'hfm 6/14/2010 00:48'!
title: anObject
	" Set the receiver's query title "
	
	self querySelector: #titleFromString:.
	self optionAt: 'title' put: anObject.! !

Z3950Options subclass: #Z3950ResultSetOptions
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950ResultSetOptions commentStamp: 'hfm 9/1/2009 20:22' prior: 0!
Option map for Z39.50 result sets!

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:30'!
defaultCount

	^ Z3950Option
		default: 0
		description: 'Number of records to be retrieved'! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 6/12/2010 21:39'!
defaultCount: aValue

	^ ( Z3950Option
		default: 0
		description: 'Number of records to be retrieved' )
		value: aValue! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:32'!
defaultElementSetName

	^ Z3950Option
		default: nil
		description: 'Element-Set name of records. Most targets should honor element set name B and F for Brief and Full respectively'! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/2/2009 00:05'!
defaultPreferredRecordSyntax

	^ (Z3950Option
		default: nil
		description: 'Preferred Syntax, such as USMARC, STURS, etc')
		values: Z3950RecordTypeFormat names! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 6/12/2010 15:58'!
defaultPreferredRecordSyntax: aValue

	^ (Z3950Option
		default: nil
		description: 'Preferred Syntax, such as USMARC, STURS, etc')
		values: Z3950RecordTypeFormat names;
		value: aValue! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:31'!
defaultPresentChunk

	^ Z3950Option
		default: 0
		description: 'The number of records to be requested from the server in each chunk (present request). The value 0 means to request all the records in a single chunk. (The old step option is also supported)'! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 19:36'!
defaultRpnCharset

	^ Z3950Option
		default: nil
		description: 'Character set for RPN terms. If this is set, ZOOM C will assume that the ZOOM application is running UTF-8. Terms in RPN queries are then converted to the rpnCharset. If this is unset, ZOOM C will not assume any encoding of RPN terms and no conversion is performed'! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 19:34'!
defaultSchema

	^ Z3950Option
		default: nil
		description: 'Schema for retrieval, such as Gils-schema, Geo-schema'
		"possibleValues: Z3950SchemasTypes names"! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 19:35'!
defaultSetname

	^ Z3950Option
		default: 'default'
		description: 'Name of Result Set (Result Set ID). If this option isn''t set, the ZOOM module will automatically allocate a result set name'! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/2/2009 00:05'!
defaultSource

	^ (Z3950Option
		default: nil
		description: 'Specifies the format of the returned record')
		values: Z3950RecordSourceType names! !

!Z3950ResultSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 18:29'!
defaultStart

	^ Z3950Option
		default: 0
		description: 'Offset of first record to be retrieved from target. First record has offset 0 unlike the protocol specifications where first record has position 1'! !

!Z3950ResultSetOptions class methodsFor: 'accessing' stamp: 'hfm 6/12/2010 15:59'!
options

	^ Dictionary new
		at: 'start' put: self defaultStart;
		at: 'count' put: self defaultCount;
		at: 'presentChunk' put: self defaultPresentChunk;
		at: 'elementSetName' put: self defaultElementSetName;
		at: 'preferredRecordSyntax' put: self defaultPreferredRecordSyntax;
		at: 'schema' put: self defaultSchema;
		at: 'setname' put: self defaultSetname;
		at: 'rpnCharset' put: self defaultRpnCharset;
		yourself! !

!Z3950ResultSetOptions methodsFor: 'initialize-release' stamp: 'hfm 6/12/2010 15:58'!
initializeWith: anObject
	" Set the receiver's server "

	options := self class options.
	self optionAt: 'preferredRecordSyntax' put:  ( self class defaultPreferredRecordSyntax: anObject asZ3950Server format ).! !

Z3950Options subclass: #Z3950ScanSetOptions
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950ScanSetOptions commentStamp: 'hfm 9/1/2009 20:22' prior: 0!
Option map for Z39.50 scan operations!

!Z3950ScanSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 20:26'!
defaultNumber

	^ Z3950Option
		default: 10
		description: 'Number of Scan Terms requested in next scan. After scan it holds the actual number of terms returned'! !

!Z3950ScanSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 20:27'!
defaultPosition

	^ Z3950Option
		default: 1
		description: 'Preferred Position of term in response in next scan; actual position after completion of scan'! !

!Z3950ScanSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 20:29'!
defaultRpnCharset

	^ Z3950Option
		default: nil
		description: 'Character set for RPN terms. IF this is set, ZOOM C will assume that the ZOOM application is running UTF-8. Terms in RPN queries are then converted to the rpnCharset. If this is unset, ZOOM C will not assume any encoding of RPN terms and no conversion is performed'! !

!Z3950ScanSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 20:27'!
defaultScanStatus

	^ Z3950Option
		default: 0
		description: 'An integer indicating the Scan Status of last scan'! !

!Z3950ScanSetOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 20:27'!
defaultStepSize

	^ Z3950Option
		default: 0
		description: 'Step size'! !

!Z3950ScanSetOptions class methodsFor: 'accessing' stamp: 'hfm 9/1/2009 20:25'!
options

	^ IdentityDictionary new
		at: 'number' put: self defaultNumber;
		at: 'position' put: self defaultPosition;
		at: 'stepSize' put: self defaultStepSize;
		at: 'scanStatus' put: self defaultScanStatus;
		at: 'rpnCharset' put: self defaultRpnCharset;
		yourself! !

Z3950Options subclass: #Z3950TypeFormOptions
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Options'!

!Z3950TypeFormOptions commentStamp: 'hfm 9/1/2009 19:42' prior: 0!
Support for the type parameter in the ZOOM_record_get function!

!Z3950TypeFormOptions class methodsFor: 'defaults' stamp: 'hfm 9/1/2009 20:13'!
defaultOutputEncoding

	^ Z3950Option
		default: 'iso-8859-1' 
		description: 'Specifies the output (returned) character set encoding. If ommited UTF-8 is assumed.'! !

!Z3950TypeFormOptions class methodsFor: 'defaults' stamp: 'hfm 9/2/2009 00:15'!
defaultSource

	^ (Z3950Option
		default: 'render'
		description: 'Specifies the format of the returned record')
		values: Z3950RecordSourceType names! !

!Z3950TypeFormOptions class methodsFor: 'defaults' stamp: 'hfm 9/2/2009 00:15'!
defaultSourceCharset

	^ (Z3950Option
		default: 'marc8'
		description: 'Specifies the character set of the record in its original form (as returned by the server)')
		values: Z3950RecordCharsetType names! !

!Z3950TypeFormOptions class methodsFor: 'accessing' stamp: 'hfm 9/2/2009 00:13'!
options

	^ Dictionary new
		at: 'from' put: self defaultSource;
		at: 'charset' put: self defaultSourceCharset;
		at: 'to' put: self defaultOutputEncoding;
		yourself! !

!Z3950TypeFormOptions methodsFor: 'initialize-release' stamp: 'hfm 9/2/2009 00:07'!
initializeWithDefaults

	options := self class options! !

!Z3950TypeFormOptions methodsFor: 'printing' stamp: 'hfm 6/12/2010 18:28'!
printOn: aStream

	aStream
		nextPutAll: ( self optionDefaultAt: 'from' ) ;
		nextPut: $;;
		nextPutAll: 'charset=';
		nextPutAll: ( self optionDefaultAt: 'charset' );
		nextPut: $,;
		nextPutAll: ( self optionDefaultAt: 'to' )
! !

Object subclass: #Z3950ServerInfo
	instanceVariableNames: 'institutionName hostName port databases format'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Data'!

!Z3950ServerInfo commentStamp: 'hfm 5/2/2009 16:30' prior: 0!
A Z39.50 particular server destination.

institutionName 		<String>			Name of the Library (most of the times)
hostName 			<String>			Net host name or IP address
port 				<Integer>		Port number of the server.
databases			<String>			Name of the databases supported on the server.
format 				<ZRecordFormat>	This could be ZMarc21, ZSUTRS or ZDanMarc!

Z3950ServerInfo subclass: #Z3950LocalServerInfo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Data'!

!Z3950LocalServerInfo commentStamp: 'hfm 5/2/2009 16:36' prior: 0!
A Z39.50 server running in the local host.!

!Z3950LocalServerInfo methodsFor: 'accessing' stamp: 'hfm 5/4/2009 14:03'!
currentServers
	" Answer a Collection of verified servers "

	^ { 
		{ 'Alameda County Public Library' . 
		'alam1.aclibrary.org' .
		210 .
		Z3950Innopac .
		Z3950Marc21 } .
		
		{ 'American Museum of Natural History ' .
		'libcat.amnh.org' .
		210 .
		Z3950Innopac .
		Z3950Marc21 }
	}! !

!Z3950LocalServerInfo methodsFor: 'initialize-release' stamp: 'hfm 5/2/2009 16:34'!
initialize
	" Private - Initialize the receiver "
	
	self hostName: 'localhost'.
	self institutionName: 'Not Applicable'.
	self port: 210.
	self databases: ''.
! !

!Z3950ServerInfo methodsFor: 'comparing' stamp: 'hfm 11/25/2009 22:18'!
<= aZ3950ServerInfo
	" Answer <true> if receiver's institutional name is less than or equal to
	aZ3950ServerInfo institutional name "
	
	^ self institutionName <= aZ3950ServerInfo institutionName! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 6/12/2010 06:07'!
asZ3950Server

	^ self ! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
databases
	^ databases! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
databases: anObject
	databases := anObject! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
format
	^ format! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
format: anObject
	format := anObject! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
hostName
	^ hostName! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
hostName: anObject
	hostName := anObject! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
institutionName
	^ institutionName! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
institutionName: anObject
	institutionName := anObject! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
port
	^ port! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 5/2/2009 16:34'!
port: anObject
	port := anObject! !

!Z3950ServerInfo methodsFor: 'accessing' stamp: 'hfm 12/22/2010 21:35'!
portNumber

	^ self port asNumber! !

!Z3950ServerInfo methodsFor: 'printing' stamp: 'hfm 11/25/2009 19:53'!
printOn: aStream

	aStream 
		nextPutAll: self institutionName;
		space;
		nextPut: $(;
		nextPutAll: self databases;
		nextPut: $/;
		nextPutAll: self format;
		nextPut: $).! !

Object subclass: #Z3950ServerRepository
	instanceVariableNames: 'servers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-Data'!

!Z3950ServerRepository commentStamp: 'hfm 5/2/2009 16:38' prior: 0!
Mantains a list of Z39.50 servers.!

!Z3950ServerRepository class methodsFor: 'instance creation' stamp: 'hfm 5/4/2009 14:08'!
new
	" Answer a new Z39.50 server repository "

	^ super new initialize! !

!Z3950ServerRepository methodsFor: 'accessing' stamp: 'hfm 5/4/2009 19:39'!
addServersFrom: aCollection
	" Add the servers found in aCollection to the receiver "

	aCollection do: [ : aServerInfoCol |
		| server |
		server := self createServer: aServerInfoCol second 
			port:  aServerInfoCol third
			database:  aServerInfoCol fourth 
			format:  aServerInfoCol fifth
			institution: aServerInfoCol first.
		self servers 
			at: ( self identifyInstitutionalName: aServerInfoCol first ) asSymbol
			put: server
		]
! !

!Z3950ServerRepository methodsFor: 'accessing' stamp: 'hfm 5/4/2009 19:17'!
anyOne
	" Answer a Random Z3950ServerInfo server "

	^ self servers anyOne! !

!Z3950ServerRepository methodsFor: 'accessing' stamp: 'hfm 5/4/2009 13:49'!
createServer: aHostName port: aPortNumber database: aDatabaseName format: aFormatName institution: anInstitutionName
	" Answer a new Z3950ServerInfo "

	^ Z3950ServerInfo new
		institutionName: anInstitutionName;
		hostName: aHostName;
		port: aPortNumber;
		databases: aDatabaseName;
		format: aFormatName
		! !

!Z3950ServerRepository methodsFor: 'private' stamp: 'hfm 6/12/2010 04:59'!
currentServers
	" Answer a Collection of servers "

	| serversInfo serversCollection names addresses ports databases formats |
	
	serversInfo := OrderedCollection new.
	( self class class organization listAtCategoryNamed: #'*Z3950Servers' )
		do: [: each | 
			serversInfo addLast: ( self newTextParserOn: each asSymbol ) rows ].
	
	names := serversInfo fourth.
	addresses := serversInfo first.
	ports := serversInfo fifth.
	databases := serversInfo second.
	formats := serversInfo third.

	serversCollection := OrderedCollection new: names size.
	1 to: names size do: [: idx | 
		serversCollection
			add: { names at: idx .
					addresses at: idx .
					ports at: idx .
					databases at: idx .
					formats at: idx }
		].
	^ serversCollection

! !

!Z3950ServerRepository methodsFor: 'private' stamp: 'hfm 6/12/2010 04:59'!
currentServersNames
	" Answer a Collection of servers names "

	^ self currentServers collect: [ : col | col first ]

! !

!Z3950ServerRepository methodsFor: 'private' stamp: 'hfm 8/29/2009 02:47'!
identifyInstitutionalName: aString
	" Answer a String to identify the server based on aString "	

	self needsWork.
	^ (aString beginsWith: 'University')
		ifTrue: [ ( aString findTokens: ' ' ) last ]
		ifFalse: [ ( aString findTokens: ' ' ) first ]! !

!Z3950ServerRepository methodsFor: 'initialize-release' stamp: 'hfm 5/4/2009 14:07'!
initialize
	" Private - Initialize the receiver's servers "
	
	self addServersFrom: self currentServers! !

!Z3950ServerRepository methodsFor: 'private' stamp: 'hfm 6/12/2010 03:33'!
newTextParserOn: aSymbol

	^ ( SUnicolumnarTextParser on:  ( self class perform: aSymbol ) ) delimiter: $;! !

!Z3950ServerRepository methodsFor: 'accessing' stamp: 'hfm 3/29/2010 03:19'!
serverAt: aString
	" Answer a Z3950ServerInfo identified by aString "

	^ servers 
		at: aString asSymbol
		ifAbsent: [ self error: 'No such server in the repository ']! !

!Z3950ServerRepository methodsFor: 'accessing' stamp: 'hfm 11/26/2009 21:19'!
serverNames
	" Answer a Collection of the receiver's
	current servers names (human readable) "

	^ self servers values
		collect: [: each | each name ]! !

!Z3950ServerRepository methodsFor: 'accessing' stamp: 'hfm 5/4/2009 17:32'!
servers

	^ servers 
		ifNil: [ servers := IdentityDictionary new ]! !

!Z3950ServerRepository methodsFor: 'accessing' stamp: 'hfm 5/4/2009 14:07'!
servers: anObject
	servers := anObject! !

Object subclass: #ZNonTerminalQueryNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-APT'!

ZNonTerminalQueryNode subclass: #ZNTAndQueryNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-APT'!

ZNonTerminalQueryNode subclass: #ZNTOperatorNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-APT'!

ZNonTerminalQueryNode subclass: #ZNTOrQueryNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-APT'!

Object subclass: #ZQueryNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-APT'!

ZQueryNode subclass: #ZAttributeTypeNode
	instanceVariableNames: 'operator typeNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-APT'!

!ZAttributeTypeNode methodsFor: 'accessing' stamp: 'hfm 8/9/2009 17:57'!
operator
	^ operator! !

!ZAttributeTypeNode methodsFor: 'accessing' stamp: 'hfm 8/9/2009 17:57'!
operator: anObject
	operator := anObject! !

!ZAttributeTypeNode methodsFor: 'printing' stamp: 'hfm 8/9/2009 17:57'!
printOn: aStream

	aStream 
		nextPutAll: self operator;
		nextPutAll: self typeNumber;
		nextPut: $=.! !

!ZAttributeTypeNode methodsFor: 'accessing' stamp: 'hfm 8/9/2009 17:41'!
typeNumber
	^ typeNumber! !

!ZAttributeTypeNode methodsFor: 'accessing' stamp: 'hfm 8/9/2009 17:41'!
typeNumber: anObject
	typeNumber := anObject! !

ZQueryNode subclass: #ZAttributeValueNode
	instanceVariableNames: 'typeValue'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-APT'!

!ZAttributeValueNode methodsFor: 'accessing' stamp: 'hfm 8/9/2009 17:41'!
typeValue
	^ typeValue! !

!ZAttributeValueNode methodsFor: 'accessing' stamp: 'hfm 8/9/2009 17:41'!
typeValue: anObject
	typeValue := anObject! !

!ZQueryNode methodsFor: 'accessing' stamp: 'hfm 8/9/2009 02:19'!
evaluateAgainst: anObject

	^ self subclassResponsibility! !

Object subclass: #ZValueNode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Z3950-APT'!
ZOOMConnection initialize!
ZOOMOptions initialize!
ZOOMOptionsEntry initialize!
ZOOMPackage initialize!
ZOOMQuery initialize!
ZOOMRecord initialize!
ZOOMRecordType initialize!
ZOOMResultSet initialize!
ZOOMScanSet initialize!
Z3950AttributeSet initialize!
